"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTVerify = void 0;
const jose_1 = require("jose");
const url_1 = require("url");
const errors_1 = require("./errors");
__exportStar(require("./errors"), exports);
__exportStar(require("./types"), exports);
__exportStar(require("./database/abstractRepository"), exports);
__exportStar(require("./database/abstractDataSource"), exports);
function JWTVerify(options) {
    const jwksUri = new url_1.URL(options.BASE_URL.endsWith('/')
        ? options.BASE_URL + '.well-known/jwks.json'
        : options.BASE_URL + '/.well-known/jwks.json');
    const JWKS = (0, jose_1.createRemoteJWKSet)(jwksUri);
    return async (req, scopes) => {
        const authorization_header = req.header('Authorization');
        if (authorization_header === undefined) {
            throw new errors_1.JWTVerificationError('Authorization header is not set', 401);
        }
        const bearerTokenResult = /^Bearer (.*)$/.exec(authorization_header);
        if (bearerTokenResult === null || bearerTokenResult.length != 2) {
            throw new errors_1.JWTVerificationError('Authorization header is malformed', 401);
        }
        const jwt = bearerTokenResult[1];
        if (!jwt)
            throw new errors_1.JWTVerificationError('No JWT provided', 401);
        if (!options.SECURITY_ISSUER)
            throw new errors_1.JWTVerificationError('No security issuer specified', 500);
        const jwtVerifyResult = await (0, jose_1.jwtVerify)(jwt, JWKS, {
            issuer: options.SECURITY_ISSUER,
            audience: options.SECURITY_AUDIENCE,
        });
        const user = jwtVerifyResult.payload;
        if (!user.scopes || !Array.isArray(user.scopes))
            throw new errors_1.JWTVerificationError('Payload is malformed', 401);
        for (const scope of scopes) {
            if (user.scopes.includes(scope)) {
                return user;
            }
        }
        throw new errors_1.JWTVerificationError('Missing Scope: one of ' + scopes, 403);
    };
}
exports.JWTVerify = JWTVerify;
//# sourceMappingURL=index.js.map