import { FindManyOptions, FindOneOptions, FindOptionsRelations, ObjectLiteral, Repository } from 'typeorm';
import { AbstractApplicationDataSource } from './abstractDataSource';
/**
 * An abstract class for a repository.
 * @typeParam M - Type of the model.
 * @typeParam RQ - Type of possible request.
 * @typeParam RSP - Type of possible response.
 */
export declare abstract class AbstractRepository<M extends ObjectLiteral, RQ, RSP> {
    name: string;
    protected repository?: Repository<M>;
    constructor(name: string);
    protected throwUninitializedRepositoryError(): never;
    abstract initialize(AppDataSource: AbstractApplicationDataSource): void;
    create(data?: RQ): Promise<M>;
    abstract write(model: M, data: Partial<RQ>): Promise<void>;
    save(model: M): Promise<M>;
    find(options?: FindManyOptions<M>): Promise<M[]>;
    findOne(options: FindOneOptions<M>): Promise<M | null>;
    findOneOrFail(options: FindOneOptions<M>): Promise<M>;
    abstract format(model: M): Promise<RSP>;
    remove(model: M): Promise<void>;
    protected getDefaultFindOptionsRelations(): FindOptionsRelations<M> | undefined;
}
//# sourceMappingURL=abstractRepository.d.ts.map