import Mocha from 'mocha';
import { AbstractApplicationDataSource } from '../abstractDataSource';
import { AbstractRepository } from '../abstractRepository';
import { CustomRecord, PartialTestData, RepositoryTestData, SuiteName } from './types.spec';
/**
 * An abstract class for a repository.
 * @typeParam K - Keys of the EntityData
 * @typeParam R - Type of the Repository
 */
export declare abstract class AbstractRepositoryTestSuite<K extends string, R extends AbstractRepository<object, unknown, unknown>> {
    protected entityData?: PartialTestData<K, R>;
    protected testSuites?: CustomRecord<SuiteName, Mocha.Suite>;
    protected repositoryTestData?: RepositoryTestData<K, R>;
    protected AppDataSource: AbstractApplicationDataSource;
    constructor(AppDataSource: AbstractApplicationDataSource);
    protected abstract repository: R;
    protected abstract getEntityData: () => Promise<PartialTestData<K, R>>;
    protected abstract RepositoryClass: {
        new (): R;
    };
    initialize(): Promise<void>;
    addTestToSuite(suiteName: SuiteName, test: (data: RepositoryTestData<K, R>) => Mocha.Test): void;
    addSuiteToSuite(suiteName: SuiteName, suite: (data: RepositoryTestData<K, R>) => Mocha.Suite): void;
    addSuite(suiteName: string, suite: (data: RepositoryTestData<K, R>) => Mocha.Suite): void;
    removeSuite(suiteName: SuiteName): void;
    protected resetDatabase(): Promise<void>;
    execute(): Mocha.Suite;
    abstract validateCreate(...args: Parameters<RepositoryTestData<K, R>['validateCreate']>): boolean;
    abstract validateWrite(...args: Parameters<RepositoryTestData<K, R>['validateWrite']>): boolean;
    abstract validateFormat(...args: Parameters<RepositoryTestData<K, R>['validateFormat']>): boolean;
    abstract compareModels(...args: Parameters<RepositoryTestData<K, R>['compareModels']>): boolean;
    abstract compareFormatted(...args: Parameters<RepositoryTestData<K, R>['compareFormatted']>): boolean;
    abstract getFindOptionsWhere(...args: Parameters<RepositoryTestData<K, R>['getFindOptionsWhere']>): ReturnType<RepositoryTestData<K, R>['getFindOptionsWhere']>;
}
//# sourceMappingURL=abstractRepository.spec.d.ts.map